@@ -3,6 +3,7 @@
 #[cfg(test)]
 pub(crate) use crate::add_port;
 
+pub(crate) use crate::cli;
 pub(crate) use crate::client;
 pub(crate) use crate::config;
 pub(crate) use crate::config::requirements::{NodeProvidedCaps, Requirements};
@@ -11,8 +12,9 @@ pub(crate) use crate::protocol;
 pub(crate) use crate::server;
 pub(crate) use crate::transport;
 
-pub(crate) use crate::server::JobIdentifier;
+pub(crate) use crate::server::JobSetIdentifier;
 
+pub(crate) use std::fs;
 pub(crate) use std::path::Path;
 pub(crate) use std::path::PathBuf;
 pub(crate) use tokio::io::{AsyncRead, AsyncWrite};
@@ -23,6 +25,7 @@ pub(crate) use tokio::sync::mpsc;
 pub(crate) use tokio::sync::oneshot;
 
 pub(crate) use std::collections::BTreeSet;
+pub(crate) use std::fmt;
 pub(crate) use std::io::{Read, Write};
 pub(crate) use std::marker::PhantomData;
 pub(crate) use std::net::SocketAddr;
@@ -31,3 +34,5 @@ pub(crate) use std::time::Duration;
 
 pub(crate) use derive_more::{Constructor, Display, From, Unwrap};
 pub(crate) use serde::{Deserialize, Serialize};
+
+pub(crate) use tracing::instrument;
