@@ -6,7 +6,7 @@ use std::sync::atomic::Ordering;
 
 use super::send_files::{ClientSendFilesState, SendFiles};
 
-#[derive(Default)]
+#[derive(Default, Debug)]
 pub(crate) struct Executing;
 
 pub(crate) struct ClientExecutingState {
@@ -22,12 +22,12 @@ pub(crate) struct ServerExecutingState {
     pub(super) common: super::Common,
     pub(super) job_name: String,
     pub(super) save_location: PathBuf,
-    // pub(crate) here so we can pull this out of the state if we need to
+    // pub(super) here so we can pull this out of the state if we need to
     pub(super) task_info: server::pool_data::RunTaskInfo,
 }
 
 impl ServerExecutingState {
-    fn job_identifier(&self) -> JobIdentifier {
+    fn job_identifier(&self) -> JobSetIdentifier {
         self.task_info.identifier
     }
 
@@ -55,6 +55,7 @@ pub(crate) enum ServerError {
 }
 
 impl Machine<Executing, ClientExecutingState> {
+    #[instrument(skip(self), fields(job_name=self.state.job.name()))]
     pub(crate) async fn execute_job(
         mut self,
     ) -> Result<
@@ -215,6 +216,15 @@ impl Machine<Executing, ClientExecutingState> {
 }
 
 impl Machine<Executing, ServerExecutingState> {
+    #[instrument(
+        skip(self, scheduler_tx), 
+        fields(
+            node_meta = %self.state.common.node_meta,
+            namespace = self.state.task_info.namespace,
+            batch_name = self.state.task_info.batch_name,
+            job_name = self.state.job_name,
+        )
+    )]
     pub(crate) async fn wait_job_execution(
         mut self,
         // the handler to the job scheduler that we can use
@@ -235,7 +245,7 @@ impl Machine<Executing, ServerExecutingState> {
 
         let keepalive_checker = server::node::complete_on_ping_failure(
             self.state.common.keepalive_addr,
-            &self.state.common.node_name,
+            &self.state.common.node_meta,
         );
 
         let msg_result = tokio::select!(
@@ -257,7 +267,7 @@ impl Machine<Executing, ServerExecutingState> {
 
         match msg {
             ClientMsg::FailedKeepalive => {
-                info!("{} job failed keepalive check", self.state.common.node_name);
+                info!("{} job failed keepalive check", self.state.common.node_meta);
 
                 let tmp = self.state.conn.transport_data(&ServerMsg::Continue).await;
                 throw_error_with_self!(tmp, self);
@@ -272,7 +282,7 @@ impl Machine<Executing, ServerExecutingState> {
             ClientMsg::Cancelled => {
                 info!(
                     "{} job was cancelled (job name {}, batch name {})",
-                    self.state.common.node_name,
+                    self.state.common.node_meta,
                     self.state.job_name,
                     self.state.batch_name()
                 );
@@ -284,7 +294,13 @@ impl Machine<Executing, ServerExecutingState> {
                 // have any practical effect on anything - nothing in this jobset
                 // really matters anymore so we dont need to create a special cancellation notice
                 info!("sending scheduler message that the job has been finished");
-                let mark_finished_msg = server::JobRequest::FinishJob(self.state.job_identifier());
+
+                let finish_msg = server::pool_data::FinishJob {
+                    ident: self.state.job_identifier(),
+                    job_name: self.state.job_name.clone(),
+                };
+
+                let mark_finished_msg = server::JobRequest::FinishJob(finish_msg);
                 scheduler_tx
                     .send(mark_finished_msg)
                     .await
@@ -334,7 +350,10 @@ impl Machine<Executing, ServerExecutingState> {
         } = self.state;
         let conn = conn.update_state();
         let state = super::uninit::ServerUninitState { conn, common };
-        debug!("moving client executing -> uninit");
+        debug!(
+            "moving {} client executing -> uninit",
+            state.common.node_meta
+        );
 
         (Machine::from_state(state), task_info)
     }
@@ -342,7 +361,7 @@ impl Machine<Executing, ServerExecutingState> {
     async fn into_send_files_state(self) -> super::send_files::ServerSendFilesState {
         debug!(
             "moving {} server executing -> send files",
-            self.state.common.node_name
+            self.state.common.node_meta
         );
         let ServerExecutingState {
             conn,
@@ -370,7 +389,7 @@ impl Machine<Executing, ServerExecutingState> {
     async fn into_prepare_build_state(self) -> super::prepare_build::ServerPrepareBuildState {
         debug!(
             "moving {} server executing -> prepare build",
-            self.state.common.node_name
+            self.state.common.node_meta
         );
         let ServerExecutingState { conn, common, .. } = self.state;
 
@@ -384,7 +403,7 @@ impl Machine<Executing, ServerExecutingState> {
     }
 
     pub(crate) fn node_name(&self) -> &str {
-        &self.state.common.node_name
+        &self.state.common.node_meta.node_name
     }
 }
 
@@ -604,7 +623,7 @@ async fn cancel_run() {
 
     let (cancel_tx, common) =
         protocol::Common::test_configuration(transport_addr, keepalive_addr, cancel_addr);
-    let job_identifier = server::JobIdentifier::Identity(1);
+    let job_identifier = server::JobSetIdentifier::Identity(1);
 
     let task_info = server::pool_data::RunTaskInfo {
         namespace: "test_namespace".into(),
@@ -669,8 +688,8 @@ async fn cancel_run() {
     // check the scheduler receiving pipe to ensure that it has been informed that
     // a job was cancelled
     let scheduler_msg = scheduler_rx.recv().await.unwrap();
-    if let server::pool_data::JobRequest::FinishJob(job_ident) = scheduler_msg {
-        assert!(job_ident == job_identifier)
+    if let server::pool_data::JobRequest::FinishJob(finish_msg) = scheduler_msg {
+        assert!(finish_msg.ident == job_identifier)
     } else {
         panic!("server did not correctly mark job as finished when it was cancelled")
     }
