@@ -10,7 +10,7 @@ const LARGE_FILE_BYTE_THRESHOLD: u64 = 10u64.pow(9);
 #[cfg(test)]
 const LARGE_FILE_BYTE_THRESHOLD: u64 = 1000;
 
-#[derive(Default)]
+#[derive(Default, Debug)]
 pub(crate) struct SendFiles;
 
 pub(crate) struct ClientSendFilesState {
@@ -31,7 +31,7 @@ pub(crate) struct ServerSendFilesState {
 }
 
 impl ServerSendFilesState {
-    fn job_identifier(&self) -> JobIdentifier {
+    fn job_identifier(&self) -> JobSetIdentifier {
         self.task_info.identifier
     }
 
@@ -70,6 +70,7 @@ impl Machine<SendFiles, ClientSendFilesState> {
     ///
     /// if there is an error reading a file, that file will be logged but not sent. The
     /// only possible error from this function is if the TCP connection is cut.
+    #[instrument(skip(self), fields(job_name=self.state.job_name))]
     pub(crate) async fn send_files(
         mut self,
     ) -> Result<Machine<Built, ClientBuiltState>, (Self, ClientError)> {
@@ -223,13 +224,22 @@ impl Machine<SendFiles, ClientSendFilesState> {
 impl Machine<SendFiles, ServerSendFilesState> {
     /// listen for the compute node to send us all the files that are in the ./distribute_save
     /// directory after the job has been completed
+    #[instrument(
+        skip(self, scheduler_tx), 
+        fields(
+            node_meta = %self.state.common.node_meta,
+            namespace = self.state.task_info.namespace,
+            batch_name = self.state.task_info.batch_name,
+            job_name = self.state.job_name,
+        )
+    )]
     pub(crate) async fn receive_files(
         mut self,
         scheduler_tx: &mut mpsc::Sender<server::JobRequest>,
     ) -> Result<Machine<Built, ServerBuiltState>, (Self, ServerError)> {
         // create the namesapce and batch name for this process
-        let namespace_dir = self.state.common.save_path.join(&self.state.namespace());
-        let batch_dir = namespace_dir.join(&self.state.batch_name());
+        let namespace_dir = self.state.common.save_path.join(self.state.namespace());
+        let batch_dir = namespace_dir.join(self.state.batch_name());
         let job_dir = batch_dir.join(&self.state.job_name);
 
         // create directories, with error handling
@@ -252,7 +262,7 @@ impl Machine<SendFiles, ServerSendFilesState> {
                         debug!(
                             "creating file {} on {} for {}",
                             path.display(),
-                            self.state.common.node_name,
+                            self.state.common.node_meta,
                             self.state.job_name
                         );
 
@@ -272,7 +282,7 @@ impl Machine<SendFiles, ServerSendFilesState> {
                         debug!(
                             "creating directory {} on {} for {}",
                             path.display(),
-                            self.state.common.node_name,
+                            self.state.common.node_meta,
                             self.state.job_name
                         );
 
@@ -328,19 +338,21 @@ impl Machine<SendFiles, ServerSendFilesState> {
                 }
                 ClientMsg::FinishFiles => {
                     // first, tell the scheduler that this job has finished
+                    let finish_msg = server::pool_data::FinishJob {
+                        ident: self.state.job_identifier(),
+                        job_name: self.state.job_name.clone(),
+                    };
                     if let Err(_e) = scheduler_tx
-                        .send(server::pool_data::JobRequest::FinishJob(
-                            self.state.job_identifier(),
-                        ))
+                        .send(server::pool_data::JobRequest::FinishJob(finish_msg))
                         .await
                     {
                         error!(
                             "scheduler is down - cannot transmit that job {} has finished on {}",
-                            self.state.job_name, self.state.common.node_name
+                            self.state.job_name, self.state.common.node_meta
                         );
                         panic!(
                             "scheduler is down - cannot transmit that job {} has finished on {}",
-                            self.state.job_name, self.state.common.node_name
+                            self.state.job_name, self.state.common.node_meta
                         );
                     }
 
@@ -363,7 +375,7 @@ impl Machine<SendFiles, ServerSendFilesState> {
     async fn into_built_state(self) -> super::built::ServerBuiltState {
         debug!(
             "moving {} server send files -> built",
-            self.state.common.node_name
+            self.state.common.node_meta
         );
         let ServerSendFilesState {
             conn,
@@ -403,13 +415,16 @@ impl Machine<SendFiles, ServerSendFilesState> {
         } = self.state;
         let conn = conn.update_state();
         let state = super::uninit::ServerUninitState { conn, common };
-        debug!("moving server send files -> uninit");
+        debug!(
+            "moving {} server send files -> uninit",
+            state.common.node_meta
+        );
 
         (Machine::from_state(state), task_info)
     }
 
     pub(crate) fn node_name(&self) -> &str {
-        &self.state.common.node_name
+        &self.state.common.node_meta.node_name
     }
 
     pub(crate) fn job_name(&self) -> &str {
@@ -512,7 +527,7 @@ async fn transport_files_with_large_file() {
     let task_info = server::pool_data::RunTaskInfo {
         namespace: namespace.clone(),
         batch_name: batch_name.clone(),
-        identifier: server::JobIdentifier::none(),
+        identifier: server::JobSetIdentifier::none(),
         task: transport::JobOpt::placeholder_test_data(),
     };
 
