@@ -1,5 +1,5 @@
 use super::ok_if_exists;
-use super::schedule::JobIdentifier;
+use super::schedule::JobSetIdentifier;
 use super::storage;
 use crate::config::requirements::{NodeProvidedCaps, Requirements};
 
@@ -21,18 +21,25 @@ pub(crate) enum JobRequest {
     QueryRemainingJobs(RemainingJobsQuery),
     CancelBatchByName(CancelBatchQuery),
     MarkBuildFailure(MarkBuildFailure),
-    FinishJob(JobIdentifier),
+    FinishJob(FinishJob),
+}
+
+#[derive(PartialEq)]
+pub(crate) struct FinishJob {
+    pub(crate) ident: JobSetIdentifier,
+    pub(crate) job_name: String,
 }
 
 pub(crate) struct MarkBuildFailure {
-    pub(crate) ident: JobIdentifier,
+    pub(crate) ident: JobSetIdentifier,
 }
 
 pub(crate) struct NewJobRequest {
     pub(crate) tx: oneshot::Sender<JobResponse>,
-    pub(crate) initialized_job: JobIdentifier,
+    pub(crate) initialized_job: JobSetIdentifier,
     pub(crate) capabilities: Arc<Requirements<NodeProvidedCaps>>,
-    pub(crate) build_failures: BTreeSet<JobIdentifier>,
+    pub(crate) build_failures: BTreeSet<JobSetIdentifier>,
+    pub(crate) node_meta: NodeMetadata,
 }
 
 #[derive(derive_more::Constructor)]
@@ -59,14 +66,14 @@ pub enum CancelResult {
 #[derive(Clone)]
 pub(crate) struct PendingJob {
     task: JobOrInit,
-    ident: JobIdentifier,
+    ident: JobSetIdentifier,
 }
 
 #[derive(From, Clone, Constructor, Debug, PartialEq)]
 pub(crate) struct TaskInfo {
     namespace: String,
     batch_name: String,
-    pub(crate) identifier: JobIdentifier,
+    pub(crate) identifier: JobSetIdentifier,
     pub(crate) task: JobOrInit,
 }
 
@@ -108,7 +115,7 @@ pub(crate) enum FetchedJob {
 pub(crate) struct BuildTaskInfo {
     pub(crate) namespace: String,
     pub(crate) batch_name: String,
-    pub(crate) identifier: JobIdentifier,
+    pub(crate) identifier: JobSetIdentifier,
     pub(crate) task: transport::BuildOpts,
 }
 
@@ -130,7 +137,7 @@ impl BuildTaskInfo {
 pub(crate) struct RunTaskInfo {
     pub(crate) namespace: String,
     pub(crate) batch_name: String,
-    pub(crate) identifier: JobIdentifier,
+    pub(crate) identifier: JobSetIdentifier,
     pub(crate) task: transport::JobOpt,
 }
 
@@ -140,3 +147,32 @@ pub(crate) enum JobOrInit {
     Job(transport::JobOpt),
     JobInit(transport::BuildOpts),
 }
+
+#[derive(Display, Clone, Debug, Serialize, Deserialize)]
+#[display(fmt = "{node_name} : {node_address}")]
+/// information about the compute node that is stored on the scheduling server.
+///
+/// This is a nice wrapper that is shared in different places. It contains the
+/// name of the node (as defined in the .yaml config file for the node) and the
+/// main transport address used to reach the node.
+pub(crate) struct NodeMetadata {
+    pub(crate) node_name: String,
+    pub(crate) node_address: SocketAddr,
+}
+
+#[cfg(test)]
+impl NodeMetadata {
+    pub(crate) fn by_name(name: &str) -> Self {
+        Self {
+            node_name: name.to_owned(),
+            node_address: ([0, 0, 0, 0], 0).into(),
+        }
+    }
+
+    pub(crate) fn test_name() -> Self {
+        Self {
+            node_name: "Test Name".to_owned(),
+            node_address: ([0, 0, 0, 0], 0).into(),
+        }
+    }
+}
