@@ -1,5 +1,5 @@
 use super::matrix;
-use super::pool_data::{JobOrInit, JobResponse, TaskInfo};
+use super::pool_data::{JobOrInit, JobResponse, NodeMetadata, TaskInfo};
 use super::storage::{self, StoredJob, StoredJobInit};
 
 use crate::config::{self, requirements};
@@ -14,48 +14,51 @@ use std::sync::Arc;
 pub(crate) trait Schedule {
     fn fetch_new_task(
         &mut self,
-        current_compiled_job: JobIdentifier,
+        current_compiled_job: JobSetIdentifier,
         node_caps: Arc<requirements::Requirements<requirements::NodeProvidedCaps>>,
-        build_failures: &BTreeSet<JobIdentifier>,
+        build_failures: &BTreeSet<JobSetIdentifier>,
+        node_meta: NodeMetadata,
     ) -> JobResponse;
 
     fn insert_new_batch(&mut self, jobs: storage::OwnedJobSet) -> Result<(), ScheduleError>;
 
-    fn add_job_back(&mut self, job: transport::JobOpt, identifier: JobIdentifier);
+    fn add_job_back(&mut self, job: transport::JobOpt, identifier: JobSetIdentifier);
 
-    fn finish_job(&mut self, job: JobIdentifier);
+    fn finish_job(&mut self, job: JobSetIdentifier, job_name: &str);
 
     /// fetch all of the batch names and associated jobs that are still running
     fn remaining_jobs(&self) -> Vec<RemainingJobs>;
 
     /// find a job identifier associated with the name of a certain job
-    fn identifier_by_name(&self, batch_name: &str) -> Option<JobIdentifier>;
+    fn identifier_by_name(&self, batch_name: &str) -> Option<JobSetIdentifier>;
 
-    fn mark_build_failure(&mut self, failed_ident: JobIdentifier, total_nodes: usize);
+    fn mark_build_failure(&mut self, failed_ident: JobSetIdentifier, total_nodes: usize);
 
-    fn cancel_batch(&mut self, ident: JobIdentifier);
+    fn cancel_batch(&mut self, ident: JobSetIdentifier);
 }
 
 #[derive(Clone, Ord, PartialEq, Eq, PartialOrd, Copy, Display, Debug)]
-pub(crate) enum JobIdentifier {
+/// Identify a batch of jobs
+pub(crate) enum JobSetIdentifier {
     #[display(fmt = "{}", _0)]
     Identity(u64),
     #[display(fmt = "Empty")]
     None,
 }
 
-impl JobIdentifier {
+impl JobSetIdentifier {
     pub(crate) fn none() -> Self {
         Self::None
     }
+
     fn new(ident: u64) -> Self {
-        JobIdentifier::Identity(ident)
+        JobSetIdentifier::Identity(ident)
     }
 }
 
 #[derive(Constructor)]
 pub(crate) struct GpuPriority {
-    map: BTreeMap<JobIdentifier, JobSet>,
+    map: BTreeMap<JobSetIdentifier, JobSet>,
     last_identifier: u64,
     base_path: PathBuf,
     matrix: Option<matrix::MatrixData>,
@@ -69,7 +72,7 @@ impl GpuPriority {
     fn take_first_job(
         &mut self,
         node_caps: Arc<requirements::Requirements<requirements::NodeProvidedCaps>>,
-        build_failures: &BTreeSet<JobIdentifier>,
+        build_failures: &BTreeSet<JobSetIdentifier>,
     ) -> JobResponse {
         if let Some((ident, job_set)) = self
             .map
@@ -99,8 +102,9 @@ impl GpuPriority {
     /// and allow the calling function to figure out how to find the next process
     fn job_by_id(
         &mut self,
-        identifier: JobIdentifier,
-        build_failures: &BTreeSet<JobIdentifier>,
+        identifier: JobSetIdentifier,
+        build_failures: &BTreeSet<JobSetIdentifier>,
+        node_meta: &NodeMetadata,
     ) -> Option<JobResponse> {
         // make sure that any job we pull in this function
         // is actually buildable by the node requesting it
@@ -118,7 +122,7 @@ impl GpuPriority {
                     "fetching next job since there are jobs remaining in set {}",
                     identifier
                 );
-                let job = job_set.next_job().unwrap();
+                let job = job_set.next_job(node_meta).unwrap();
                 Some(JobResponse::SetupOrRun(TaskInfo::new(
                     job_set.namespace.clone(),
                     job_set.batch_name.clone(),
@@ -135,9 +139,10 @@ impl GpuPriority {
 impl Schedule for GpuPriority {
     fn fetch_new_task(
         &mut self,
-        current_compiled_job: JobIdentifier,
+        current_compiled_job: JobSetIdentifier,
         node_caps: Arc<requirements::Requirements<requirements::NodeProvidedCaps>>,
-        build_failures: &BTreeSet<JobIdentifier>,
+        build_failures: &BTreeSet<JobSetIdentifier>,
+        node_meta: NodeMetadata,
     ) -> JobResponse {
         // go through our entire job set and see if there is a gpu job
         if let Some((gpu_ident, gpu_job_set)) = self
@@ -155,7 +160,7 @@ impl Schedule for GpuPriority {
             // if we are already working on this job - we dont need to recompile anything,
             // just send the next iteration of the job out
             if current_compiled_job == *gpu_ident {
-                let job = gpu_job_set.next_job().unwrap();
+                let job = gpu_job_set.next_job(&node_meta).unwrap();
                 JobResponse::SetupOrRun(TaskInfo::new(
                     gpu_job_set.namespace.clone(),
                     gpu_job_set.batch_name.clone(),
@@ -176,7 +181,7 @@ impl Schedule for GpuPriority {
         }
         // we dont have any gpu jobs to run, just pull the first item from the map that has some
         // jobs left and we will run those
-        else if let Some(job) = self.job_by_id(current_compiled_job, build_failures) {
+        else if let Some(job) = self.job_by_id(current_compiled_job, build_failures, &node_meta) {
             job
         } else {
             self.take_first_job(node_caps, build_failures)
@@ -187,13 +192,13 @@ impl Schedule for GpuPriority {
         let jobs = JobSet::from_owned(jobs, &self.base_path).map_err(error::StoreSet::from)?;
 
         self.last_identifier += 1;
-        let ident = JobIdentifier::new(self.last_identifier);
+        let ident = JobSetIdentifier::new(self.last_identifier);
         self.map.insert(ident, jobs);
 
         Ok(())
     }
 
-    fn add_job_back(&mut self, job: transport::JobOpt, identifier: JobIdentifier) {
+    fn add_job_back(&mut self, job: transport::JobOpt, identifier: JobSetIdentifier) {
         if let Some(job_set) = self.map.get_mut(&identifier) {
             job_set.add_errored_job(job, &self.base_path)
         } else {
@@ -205,17 +210,17 @@ impl Schedule for GpuPriority {
         }
     }
 
-    fn finish_job(&mut self, identifier: JobIdentifier) {
+    fn finish_job(&mut self, identifier: JobSetIdentifier, job_name: &str) {
         debug!("called finish job with ident {}", identifier);
 
         if let Some(job_set) = self.map.get_mut(&identifier) {
-            job_set.job_finished();
+            job_set.job_finished(job_name);
 
             // if there are no more jobs to run, and the final job for this process
             // has just finished - remove the job set from the tree
-            if !job_set.has_remaining_jobs() && job_set.currently_running_jobs == 0 {
+            if !job_set.has_remaining_jobs() && job_set.running_jobs.is_empty() {
                 info!(
-                    "removeing tree with identifier {} from the queue - all jobs have finished 
+                    "removing job set with identifier {} from the queue - all jobs have finished 
                     and there are no more running jobs",
                     identifier
                 );
@@ -247,7 +252,7 @@ impl Schedule for GpuPriority {
         } else {
             error!(
                 "a job set for identifier {} was removed before all 
-               of the running jobs for the set were done. This shuould not happen",
+               of the running jobs for the set were done. This should not happen",
                 &identifier
             )
         }
@@ -255,12 +260,12 @@ impl Schedule for GpuPriority {
 
     fn remaining_jobs(&self) -> Vec<RemainingJobs> {
         self.map
-            .iter()
-            .map(|(_, job_set)| job_set.remaining_jobs())
+            .values()
+            .map(|job_set| job_set.remaining_jobs())
             .collect()
     }
 
-    fn identifier_by_name(&self, batch_name: &str) -> Option<JobIdentifier> {
+    fn identifier_by_name(&self, batch_name: &str) -> Option<JobSetIdentifier> {
         self.map
             .iter()
             .filter(|(_, set)| set.batch_name == batch_name)
@@ -268,7 +273,7 @@ impl Schedule for GpuPriority {
             .next()
     }
 
-    fn mark_build_failure(&mut self, failed_ident: JobIdentifier, total_nodes: usize) {
+    fn mark_build_failure(&mut self, failed_ident: JobSetIdentifier, total_nodes: usize) {
         if let Some((_ident, mut job_set)) = self
             .map
             .iter_mut()
@@ -315,12 +320,12 @@ impl Schedule for GpuPriority {
     /// so the overall job set must remain in the pool.
     ///
     /// Once all cancellations have been filed the job set will be dropped in another function call
-    fn cancel_batch(&mut self, ident: JobIdentifier) {
+    fn cancel_batch(&mut self, ident: JobSetIdentifier) {
         info!("cancelling batch for identifier {}", ident);
 
         if let Some(job_set) = self.map.get_mut(&ident) {
             info!(
-                "cancellation for {} corresponds to job name ",
+                "cancellation for identifier {ident} corresponds to batch name {}",
                 job_set.batch_name
             );
 
@@ -339,12 +344,12 @@ impl Schedule for GpuPriority {
     }
 }
 
-#[derive(Constructor, Debug)]
+#[derive(Debug)]
 pub(crate) struct JobSet {
     build: StoredJobInit,
     requirements: requirements::Requirements<requirements::JobRequiredCaps>,
     remaining_jobs: Vec<StoredJob>,
-    currently_running_jobs: usize,
+    running_jobs: Vec<RunningJob>,
     pub(crate) batch_name: String,
     namespace: String,
     matrix_user: Option<matrix_notify::OwnedUserId>,
@@ -356,12 +361,14 @@ impl JobSet {
         !self.remaining_jobs.is_empty()
     }
 
-    fn next_job(&mut self) -> Option<transport::JobOpt> {
+    fn next_job(&mut self, node_meta: &NodeMetadata) -> Option<transport::JobOpt> {
         if let Some(job) = self.remaining_jobs.pop() {
-            self.currently_running_jobs += 1;
+            let running_job_desc = RunningJob::new(job.job_name().to_string(), node_meta.clone());
+            self.running_jobs.push(running_job_desc);
+
             debug!(
-                "calling next_job() -> currently running jobs is now {}",
-                self.currently_running_jobs
+                "calling next_job() -> currently running jobs is now length {}",
+                self.running_jobs.len()
             );
             job.load_job().ok()
         } else {
@@ -374,7 +381,8 @@ impl JobSet {
     }
 
     fn add_errored_job(&mut self, job: transport::JobOpt, base_path: &Path) {
-        self.currently_running_jobs -= 1;
+        debug!("called add_errored_job() on corresponding job set, removing job name {} from running set list", job.name());
+        self.remove_running_job_by_name(job.name());
 
         match StoredJob::from_opt(job, base_path) {
             Ok(job) => self.remaining_jobs.push(job),
@@ -382,18 +390,31 @@ impl JobSet {
         }
     }
 
-    fn job_finished(&mut self) {
-        if self.currently_running_jobs == 0 {
-            warn!("a job from {}'s currently_running_jobs finished, but the value was already zero. This should not happen", &self.batch_name);
-        } else {
-            self.currently_running_jobs -= 1;
+    fn remove_running_job_by_name(&mut self, job_name: &str) {
+        if let Some(idx) = self
+            .running_jobs
+            .iter()
+            .enumerate()
+            .filter(|(_, running_job)| running_job.job_name == job_name)
+            .map(|(idx, _)| idx)
+            .next()
+        {
+            self.running_jobs.remove(idx);
             debug!(
-                "calling job_finished() -> currently running jobs is now {}",
-                self.currently_running_jobs
+                "calling removing job of name {job_name} from current queue -> currently running jobs is now {}",
+                self.running_jobs.len()
             );
+        } else {
+            error!("failed to find job name {} in the set of running jobs for this node. Running job names are currently: {:?}", 
+                job_name, self.running_jobs.iter().map(|job| &job.job_name).collect::<Vec<_>>());
         }
     }
 
+    fn job_finished(&mut self, job_name: &str) {
+        debug!("called job_finished() on corresponding job set, removing job name {job_name} from running set list");
+        self.remove_running_job_by_name(job_name);
+    }
+
     pub(crate) fn name(&self) -> &str {
         &self.batch_name
     }
@@ -406,7 +427,11 @@ impl JobSet {
                 .iter()
                 .map(|x| x.job_name().to_string())
                 .collect(),
-            running_jobs: self.currently_running_jobs,
+            running_jobs: self
+                .running_jobs
+                .iter()
+                .map(|x| x.to_duration_information())
+                .collect(),
         }
     }
 
@@ -438,11 +463,12 @@ impl JobSet {
             build,
             requirements,
             remaining_jobs,
-            currently_running_jobs,
+            //currently_running_jobs,
             batch_name,
             matrix_user,
             namespace,
         } = owned;
+
         let build = StoredJobInit::from_opt(build, base_path)?;
         let remaining_jobs = match remaining_jobs {
             config::JobOpts::Python(python_jobs) => {
@@ -467,7 +493,7 @@ impl JobSet {
             build,
             requirements,
             remaining_jobs,
-            currently_running_jobs,
+            running_jobs: vec![],
             batch_name,
             matrix_user,
             namespace,
@@ -480,7 +506,46 @@ impl JobSet {
 pub struct RemainingJobs {
     pub batch_name: String,
     pub jobs_left: Vec<String>,
-    pub running_jobs: usize,
+    pub running_jobs: Vec<RunningJobDuration>,
+}
+
+#[derive(Clone, Debug)]
+pub struct RunningJob {
+    job_name: String,
+    /// information on the node we are running on
+    node_meta: NodeMetadata,
+    start_time: std::time::Instant,
+}
+
+impl RunningJob {
+    fn new(job_name: String, node_meta: NodeMetadata) -> Self {
+        Self {
+            job_name,
+            node_meta,
+            start_time: std::time::Instant::now(),
+        }
+    }
+
+    fn to_duration_information(&self) -> RunningJobDuration {
+        let Self {
+            job_name,
+            node_meta,
+            start_time,
+        } = self.clone();
+        RunningJobDuration {
+            job_name,
+            node_meta,
+            duration: start_time.elapsed(),
+        }
+    }
+}
+
+#[derive(Serialize, Deserialize, Clone, Debug)]
+pub struct RunningJobDuration {
+    pub(crate) job_name: String,
+    /// information on the node we are running on
+    pub(crate) node_meta: NodeMetadata,
+    pub(crate) duration: std::time::Duration,
 }
 
 #[cfg(test)]
@@ -490,11 +555,15 @@ mod tests {
     use crate::server::storage::OwnedJobSet;
     use crate::transport;
 
-    fn check_init(current_ident: &mut JobIdentifier, expected_ident: u64, response: JobResponse) {
+    fn check_init(
+        current_ident: &mut JobSetIdentifier,
+        expected_ident: u64,
+        response: JobResponse,
+    ) {
         match response {
             JobResponse::SetupOrRun(task) => {
                 task.task.unwrap_job_init();
-                assert_eq!(task.identifier, JobIdentifier::Identity(expected_ident));
+                assert_eq!(task.identifier, JobSetIdentifier::Identity(expected_ident));
                 *current_ident = task.identifier;
             }
             JobResponse::EmptyJobs => {
@@ -563,7 +632,7 @@ mod tests {
                 reqs: vec!["fortran".into(), "fftw".into()].into_iter().collect(),
                 marker: std::marker::PhantomData,
             },
-            currently_running_jobs: 0,
+            //currently_running_jobs: 0,
             matrix_user: None,
         };
 
@@ -581,7 +650,7 @@ mod tests {
                 reqs: vec!["gpu".into()].into_iter().collect(),
                 marker: std::marker::PhantomData,
             },
-            currently_running_jobs: 0,
+            //currently_running_jobs: 0,
             matrix_user: None,
         };
 
@@ -593,6 +662,7 @@ mod tests {
     fn gpu_first() {
         let path = Path::new("gpu_first");
         std::fs::create_dir_all(path).unwrap();
+        let node_meta = NodeMetadata::test_name();
 
         let (cpu_set, gpu_set, mut scheduler) = init(path);
 
@@ -610,31 +680,61 @@ mod tests {
             marker: std::marker::PhantomData,
         });
 
-        let mut current_ident = JobIdentifier::none();
+        let mut current_ident = JobSetIdentifier::none();
 
         let build_failures = Default::default();
 
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_init(&mut current_ident, 2, job);
 
         // the next job out of the queue should be jgpu
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_job(job, jgpu);
 
         // we have exhausted all the gpu jobs, we now expect to setup a cpu job
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_init(&mut current_ident, 1, job);
 
         // now we expectet it to be j2
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_job(job, j2);
 
         // now we expect j1
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_job(job, j1);
 
         // now there are no more jobs left
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_empty(job);
 
         std::fs::remove_dir_all(path).ok();
@@ -645,6 +745,7 @@ mod tests {
     fn gpu_added_later() {
         let path = Path::new("gpu_added_later");
         std::fs::create_dir_all(path).unwrap();
+        let node_meta = NodeMetadata::test_name();
 
         let (cpu_set, gpu_set, mut scheduler) = init(path);
 
@@ -663,35 +764,70 @@ mod tests {
 
         let build_failures = Default::default();
 
-        let mut current_ident = JobIdentifier::none();
+        let mut current_ident = JobSetIdentifier::none();
 
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_init(&mut current_ident, 1, job);
 
         // the next job out of the queue should be jgpu
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_job(job, j2);
 
         scheduler.insert_new_batch(gpu_set).unwrap(); // 2
 
         // now that there are gpu jobs available we expect to initialize
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_init(&mut current_ident, 2, job);
 
         // and now run the gpu job
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_job(job, jgpu);
 
         // exhaused gpu jobs - now we run cpu job init again
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_init(&mut current_ident, 1, job);
 
         // now back to cpu - run j1
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_job(job, j1);
 
         // now there are no more jobs left
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_empty(job);
 
         std::fs::remove_dir_all(path).unwrap();
@@ -709,6 +845,8 @@ mod tests {
         let j1 = cpu_set.remaining_jobs.clone().unwrap_python()[0].clone();
         let j2 = cpu_set.remaining_jobs.clone().unwrap_python()[1].clone();
 
+        let node_meta = NodeMetadata::test_name();
+
         let cpu_ident = 1;
         let gpu_ident = 2;
         scheduler.insert_new_batch(cpu_set).unwrap(); // 1
@@ -725,37 +863,72 @@ mod tests {
             marker: std::marker::PhantomData,
         });
 
-        let mut curr_cpu_ident = JobIdentifier::none();
-        let mut curr_gpu_ident = JobIdentifier::none();
+        let mut curr_cpu_ident = JobSetIdentifier::none();
+        let mut curr_gpu_ident = JobSetIdentifier::none();
 
         let build_failures = Default::default();
 
         // cpu pulls a job - it should only be a cpu job
-        let job = scheduler.fetch_new_task(curr_cpu_ident, caps_cpu.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            curr_cpu_ident,
+            caps_cpu.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_init(&mut curr_cpu_ident, cpu_ident, job);
 
         // gpu pulls a job - it should be a GPU job
-        let job = scheduler.fetch_new_task(curr_gpu_ident, caps_gpu.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            curr_gpu_ident,
+            caps_gpu.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_init(&mut curr_gpu_ident, gpu_ident, job);
 
         // gpu job has built - we pull a job with those caps
-        let job = scheduler.fetch_new_task(curr_gpu_ident, caps_gpu.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            curr_gpu_ident,
+            caps_gpu.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_job(job, jgpu);
 
         // cpu job now pulls its first job
-        let job = scheduler.fetch_new_task(curr_cpu_ident, caps_cpu.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            curr_cpu_ident,
+            caps_cpu.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_job(job, j2);
 
         // gpu job has finished - it should get an initialization for the gpu job now
-        let job = scheduler.fetch_new_task(curr_gpu_ident, caps_gpu.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            curr_gpu_ident,
+            caps_gpu.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_init(&mut curr_gpu_ident, cpu_ident, job);
 
         // gpu init has finished - it pulls again and gets j1
-        let job = scheduler.fetch_new_task(curr_gpu_ident, caps_gpu.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            curr_gpu_ident,
+            caps_gpu.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_job(job, j1);
 
         // cpu task pulls and there is nothing left
-        let job = scheduler.fetch_new_task(curr_cpu_ident, caps_cpu.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            curr_cpu_ident,
+            caps_cpu.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_empty(job);
 
         std::fs::remove_dir_all(path).unwrap();
@@ -767,6 +940,7 @@ mod tests {
     fn dont_send_failed_builds() {
         let path = Path::new("dont_send_failed_builds");
         std::fs::create_dir_all(path).unwrap();
+        let node_meta = NodeMetadata::test_name();
 
         let (cpu_set, _gpu_set, mut scheduler) = init(path);
         scheduler.insert_new_batch(cpu_set).unwrap();
@@ -780,9 +954,14 @@ mod tests {
             marker: std::marker::PhantomData,
         });
 
-        let mut current_ident = JobIdentifier::none();
+        let mut current_ident = JobSetIdentifier::none();
 
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         check_init(&mut current_ident, 1, job);
 
         // now we tell them that we failed to build the job
@@ -792,7 +971,12 @@ mod tests {
         scheduler.mark_build_failure(current_ident, 2);
 
         // ask for a new job, it should be a build request to the next job
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(
+            current_ident,
+            caps.clone(),
+            &build_failures,
+            node_meta.clone(),
+        );
         assert_eq!(job, JobResponse::EmptyJobs);
 
         std::fs::remove_dir_all(path).ok();
@@ -808,15 +992,16 @@ mod tests {
         scheduler.insert_new_batch(cpu_set).unwrap();
 
         let build_failures = BTreeSet::new();
+        let node_meta = NodeMetadata::test_name();
 
         let caps = Arc::new(Requirements {
             reqs: vec!["fortran".into(), "fftw".into()].into_iter().collect(),
             marker: std::marker::PhantomData,
         });
 
-        let mut current_ident = JobIdentifier::none();
+        let mut current_ident = JobSetIdentifier::none();
 
-        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures);
+        let job = scheduler.fetch_new_task(current_ident, caps.clone(), &build_failures, node_meta);
         check_init(&mut current_ident, 1, job);
 
         // now we tell them that we failed to build the job
