@@ -91,6 +91,8 @@ pub struct PullFileRequest {
     // whether or not to only pull matching and non-matching files and skip pulling
     // the actual data
     pub(crate) dry: bool,
+    // skip sending all folders since we have built a folder structure previously
+    pub(crate) skip_folders: bool,
 }
 
 #[derive(Deserialize, Serialize, Debug, derive_more::From, derive_more::Unwrap, Display)]
@@ -135,27 +137,56 @@ pub struct PullFilesDryResponse {
     pub filtered_files: Vec<PathBuf>,
 }
 
-#[derive(Deserialize, Serialize, Debug, Clone, PartialEq, Eq)]
+#[derive(Deserialize, Serialize, Clone, PartialEq, Eq)]
 pub struct PythonJobInit {
     pub batch_name: String,
     pub python_setup_file: Vec<u8>,
     pub additional_build_files: Vec<File>,
 }
 
-#[derive(Deserialize, Serialize, Debug, Clone, PartialEq, Eq)]
+impl fmt::Debug for PythonJobInit {
+    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
+        fmt.debug_struct("PythonJobInit")
+            .field("batch_name", &self.batch_name)
+            .field("python_setup_file (length)", &self.python_setup_file.len())
+            .field("additional_build_files", &self.additional_build_files)
+            .finish()
+    }
+}
+
+#[derive(Deserialize, Serialize, Clone, PartialEq, Eq)]
 pub struct File {
     pub file_name: String,
     pub file_bytes: Vec<u8>,
 }
 
-#[derive(Deserialize, Serialize, Debug, Clone, PartialEq, Eq)]
+impl fmt::Debug for File {
+    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
+        fmt.debug_struct("File")
+            .field("file_name", &self.file_name)
+            .field("file_bytes (length)", &self.file_bytes.len())
+            .finish()
+    }
+}
+
+#[derive(Deserialize, Serialize, Clone, PartialEq, Eq)]
 pub struct PythonJob {
     pub python_file: Vec<u8>,
     pub job_name: String,
     pub job_files: Vec<File>,
 }
 
-#[derive(Deserialize, Serialize, Debug, Clone, PartialEq, Eq)]
+impl fmt::Debug for PythonJob {
+    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
+        fmt.debug_struct("PythonJob")
+            .field("job_name", &self.job_name)
+            .field("job_files", &self.job_files)
+            .field("python_file (length)", &self.python_file.len())
+            .finish()
+    }
+}
+
+#[derive(Deserialize, Serialize, Clone, PartialEq, Eq)]
 pub struct ApptainerJobInit {
     pub batch_name: String,
     pub sif_bytes: Vec<u8>,
@@ -163,12 +194,31 @@ pub struct ApptainerJobInit {
     pub container_bind_paths: Vec<PathBuf>,
 }
 
-#[derive(Deserialize, Serialize, Debug, Clone, PartialEq, Eq)]
+impl fmt::Debug for ApptainerJobInit {
+    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
+        fmt.debug_struct("ApptainerJobInit")
+            .field("batch_name", &self.batch_name)
+            .field("build_files", &self.build_files)
+            .field("container_bind_paths", &self.container_bind_paths)
+            .finish()
+    }
+}
+
+#[derive(Deserialize, Serialize, Clone, PartialEq, Eq)]
 pub struct ApptainerJob {
     pub job_name: String,
     pub job_files: Vec<File>,
 }
 
+impl fmt::Debug for ApptainerJob {
+    fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
+        fmt.debug_struct("ApptainerJob")
+            .field("job_name", &self.job_name)
+            .field("job_files", &self.job_files)
+            .finish()
+    }
+}
+
 #[derive(derive_more::From, Serialize, Deserialize, Clone, Debug, PartialEq, Eq)]
 #[cfg(feature = "cli")]
 pub enum BuildOpts {
@@ -262,6 +312,12 @@ pub(crate) struct Connection<T> {
     _marker: std::marker::PhantomData<T>,
 }
 
+impl<T> fmt::Debug for Connection<T> {
+    fn fmt(&self, fmt: &mut fmt::Formatter) -> fmt::Result {
+        write!(fmt, "connection transporting {} messages", stringify!(T))
+    }
+}
+
 impl<TX, RX> Connection<TX>
 where
     TX: Serialize + AssociatedMessage<Receive = RX>,
